@@ -11,7 +11,7 @@ def fail(msg):
 def main():
     fail(
         "This installation method has been deprecated. "
-        "See https://github.com/pipxproject/pipx for current installation "
+        "See https://github.com/pypa/pipx for current installation "
         "instructions."
     )
 
