@@ -16,6 +16,7 @@ from pathlib import Path
 from typing import Any, Callable, Dict, List
 
 import argcomplete  # type: ignore
+from packaging.requirements import InvalidRequirement, Requirement
 from packaging.utils import canonicalize_name
 
 import pipx.constants
@@ -25,7 +26,7 @@ from pipx.colors import bold, green
 from pipx.constants import ExitCode
 from pipx.emojis import hazard
 from pipx.interpreter import DEFAULT_PYTHON
-from pipx.util import PipxError, mkdir, pipx_wrap
+from pipx.util import PipxError, mkdir, pipx_wrap, rmdir
 from pipx.venv import VenvContainer
 from pipx.version import __version__
 
@@ -175,9 +176,17 @@ def run_pipx_command(args: argparse.Namespace) -> ExitCode:  # noqa: C901
             if ("spec" in args and args.spec is not None)
             else args.app_with_args[0]
         )
+        # For any package, we need to just use the name
+        try:
+            package_name = Requirement(args.app_with_args[0]).name
+        except InvalidRequirement:
+            # Raw URLs to scripts are supported, too, so continue if
+            # we can't parse this as a package
+            package_name = args.app_with_args[0]
+
         use_cache = not args.no_cache
         commands.run(
-            args.app_with_args[0],
+            package_name,
             package_or_url,
             args.app_with_args[1:],
             args.python,
@@ -489,7 +498,7 @@ def _add_list(subparsers: argparse._SubParsersAction) -> None:
         help="Show packages injected into the main app's environment",
     )
     p.add_argument(
-        "--json", action="store_true", help="Output rich data in json format.",
+        "--json", action="store_true", help="Output rich data in json format."
     )
     p.add_argument("--verbose", action="store_true")
 
@@ -602,8 +611,11 @@ def get_command_parser() -> argparse.ArgumentParser:
     completer_venvs = InstalledVenvsCompleter(venv_container)
 
     parser = argparse.ArgumentParser(
-        formatter_class=LineWrapRawTextHelpFormatter, description=PIPX_DESCRIPTION
+        prog="pipx",
+        formatter_class=LineWrapRawTextHelpFormatter,
+        description=PIPX_DESCRIPTION,
     )
+    parser.man_short_description = PIPX_DESCRIPTION.splitlines()[1]  # type: ignore
 
     subparsers = parser.add_subparsers(
         dest="command", description="Get help for commands with pipx COMMAND --help"
@@ -721,6 +733,8 @@ def setup(args: argparse.Namespace) -> None:
     mkdir(constants.LOCAL_BIN_DIR)
     mkdir(constants.PIPX_VENV_CACHEDIR)
 
+    rmdir(constants.PIPX_TRASH_DIR, False)
+
     old_pipx_venv_location = constants.PIPX_LOCAL_VENVS / "pipx-app"
     if old_pipx_venv_location.exists():
         logger.warning(
@@ -729,7 +743,7 @@ def setup(args: argparse.Namespace) -> None:
                 {hazard}  A virtual environment for pipx was detected at
                 {str(old_pipx_venv_location)}. The 'pipx-app' package has been
                 renamed back to 'pipx'
-                (https://github.com/pipxproject/pipx/issues/82).
+                (https://github.com/pypa/pipx/issues/82).
                 """,
                 subsequent_indent=" " * 4,
             )
