@@ -273,9 +273,7 @@ PKG: Dict[str, Dict[str, Any]] = {
     "howdoi": {
         "spec": "howdoi==2.0.7",
         "apps": _exe_if_win(["howdoi"]),
-        "apps_of_dependencies": _exe_if_win(
-            ["chardetect", "keep", "pygmentize", "pyjwt"]
-        ),
+        "apps_of_dependencies": _exe_if_win(["chardetect", "keep", "pygmentize"]),
     },
     "httpie": {
         "spec": "httpie==2.3.0",
@@ -340,10 +338,10 @@ PKG: Dict[str, Dict[str, Any]] = {
         ),
     },
     "kaggle": {
-        "spec": "kaggle==1.5.9",
+        "spec": "kaggle==1.5.12",
         "apps": _exe_if_win(["kaggle"]),
         "apps_of_dependencies": list(
-            set(_exe_if_win(["chardetect", "slugify", "tqdm"]) + ["slugify"])
+            set(_exe_if_win(["chardetect", "slugify", "tqdm"]))
         ),
     },
     "kibitzr": {
@@ -486,6 +484,7 @@ PKG: Dict[str, Dict[str, Any]] = {
             "register-python-argcomplete",
         ],  # from argcomplete
     },
+    "pbr": {"spec": "pbr==5.6.0", "apps": _exe_if_win(["pbr"])},
     "pelican": {
         "spec": "pelican==4.5.0",
         "apps": _exe_if_win(
@@ -579,6 +578,7 @@ PKG: Dict[str, Dict[str, Any]] = {
         "apps": _exe_if_win(["pycowsay"]),
         "apps_of_dependencies": [],
     },
+    "pygdbmi": {"spec": "pygdbmi==0.10.0.0", "apps": [], "apps_of_dependencies": []},
     "pylint": {
         "spec": "pylint==2.3.1",
         "apps": _exe_if_win(["epylint", "pylint", "pyreverse", "symilar"]),
@@ -775,7 +775,6 @@ PKG: Dict[str, Dict[str, Any]] = {
                 "pretranslate",
                 "prop2po",
                 "pydiff",
-                "pyjwt",  # PyJWT EXE
                 "pypo2phppo",
                 "rc2po",
                 "resx2po",
